@@ -1,10 +1,10 @@
-
-# Copyright (C) 2015-2020 Joelle Maslak
+#
+# Copyright (C) 2015-2023 Joelle Maslak
 # All Rights Reserved - See License
 #
 
 package Parallel::WorkUnit;
-$Parallel::WorkUnit::VERSION = '2.232010'; # TRIAL
+$Parallel::WorkUnit::VERSION = '2.232011'; # TRIAL
 use v5.8;
 
 # ABSTRACT: Provide multi-paradigm forking with ability to pass back data
@@ -550,7 +550,12 @@ sub _send {
     if ( $#_ != 3 ) { confess 'invalid call'; }
     my ( $self, $fh, $type, $data ) = @_;
 
-    my $msg = Storable::freeze( \$data );
+    my $msg;
+    if ( blessed($data) && ($data->can('FREEZE')) && ($data->can('THAW')) ) {
+        $msg = ref($data) . "!::!" . $data->FREEZE();
+    } else {
+        $msg = "!::!" . Storable::freeze( \$data );
+    }
 
     if ( !defined($msg) ) {
         die 'freeze() returned undef for child return value';
@@ -597,7 +602,13 @@ sub _read_result {
         if ( defined($ret) ) { $result .= $part; }
     }
 
-    my $data = ${ Storable::thaw($result) };
+    my ($class, $frozen) = split("!::!", $result);
+    my $data;
+    if ($class eq "") {
+        $data = ${ Storable::thaw($frozen) };
+    } else {
+        $data = $class->THAW($frozen);
+    }
 
     my $caller = $self->_subprocs()->{$child}{caller};
     delete $self->_subprocs()->{$child};
@@ -795,7 +806,7 @@ Parallel::WorkUnit - Provide multi-paradigm forking with ability to pass back da
 
 =head1 VERSION
 
-version 2.232010
+version 2.232011
 
 =head1 SYNOPSIS
 
@@ -1055,6 +1066,15 @@ Note that the child inherits all open file descriptors.
 Not also that the child process will be part of the same process group as the
 parent process.  Additional work is required to daemonize the child.
 
+=head1 CAVEATS
+
+This module uses L<Storable> to serialize objects, except for objects
+that have a C<FREEZE> and C<THAW> method defined, in which case those
+methods are used.  As a result, it cannot serialize some objects, such
+as C<REGEXP> (sometimes), C<CODE>, or C<OBJECT> (I.E. Corinna objects
+created with the C<class> statement in Perl 5.38+), unless these
+objects also have a C<FREEZE> and C<THAW> method defined.
+
 =head1 AUTHOR
 
 Joelle Maslak <jmaslak@antelope.net>
